**Example 1: 示例**



Input: 

```
tccli cwp DescribeMachineOsList --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "List": [
            {
                "Name": "Linux",
                "MachineOSType": 1
            }
        ],
        "RequestId": "ec6c0e16-465e-4d40-8926-823b26bd6b8s"
    }
}
```

